summaryrefslogtreecommitdiff
path: root/ext/Compress/Zlib/Zlib.pm
diff options
context:
space:
mode:
Diffstat (limited to 'ext/Compress/Zlib/Zlib.pm')
-rw-r--r--ext/Compress/Zlib/Zlib.pm6
1 files changed, 3 insertions, 3 deletions
diff --git a/ext/Compress/Zlib/Zlib.pm b/ext/Compress/Zlib/Zlib.pm
index 063c89b53f..3f409873da 100644
--- a/ext/Compress/Zlib/Zlib.pm
+++ b/ext/Compress/Zlib/Zlib.pm
@@ -1,7 +1,7 @@
# File : Zlib.pm
# Author : Paul Marquess
# Created : 6 September 2005
# Version : 1.38
#
# Copyright (c) 1995-2005 Paul Marquess. All rights reserved.
# This program is free software; you can redistribute it and/or
@@ -21,7 +21,7 @@ use warnings ;
our ($VERSION, @ISA, @EXPORT, $AUTOLOAD);
our ($deflateDefault, $deflateParamsDefault, $inflateDefault);
-$VERSION = "1.38" ;
+$VERSION = "1.39" ;
@ISA = qw(Exporter);
# Items to export into callers namespace by default. Note: do not export
@@ -1,7 +1,7 @@
# File : Zlib.pm
# Author : Paul Marquess
-# Created : 6 September 2005
-# Version : 1.38
+# Created : 7 September 2005
+# Version : 1.39
#
# Copyright (c) 1995-2005 Paul Marquess. All rights reserved.